<?php
/**
 * Classic Woocommerce functions and definitions
 *
 * @package Classic Woocommerce
 */

if ( ! function_exists( 'classic_woocommerce_setup' ) ) :
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which runs
 * before the init hook. The init hook is too late for some features, such as indicating
 * support post thumbnails.
 */

function classic_woocommerce_setup() {
	global $classic_woocommerce_content_width;
	if ( ! isset( $classic_woocommerce_content_width ) )
		$classic_woocommerce_content_width = 680;

	add_theme_support( 'responsive-embeds' );
	add_theme_support( 'automatic-feed-links' );
	add_theme_support( 'wp-block-styles');
	add_theme_support( 'align-wide' );
	add_theme_support( 'woocommerce' );
	add_theme_support( 'post-thumbnails' );
	add_theme_support( 'title-tag' );
	add_theme_support( 'custom-logo', array(
		'height'      => 100,
		'width'       => 100,
		'flex-height' => true,
	) );
	add_theme_support( 'custom-background', array(
		'default-color' => 'ffffff'
	) );
	add_theme_support( 'html5', array(
		'search-form',
		'comment-form',
		'comment-list',
		'gallery',
		'caption',
	) );
	add_editor_style( 'editor-style.css' );
}
endif; // classic_ecommerce_setup
add_action( 'after_setup_theme', 'classic_woocommerce_setup' );

function classic_woocommerce_widgets_init() {
	register_sidebar( array(
		'name'          => __( 'Blog Sidebar', 'classic-woocommerce' ),
		'description'   => __( 'Appears on blog page sidebar', 'classic-woocommerce' ),
		'id'            => 'sidebar-1',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	$classic_woocommerce_widget_areas = get_theme_mod('classic_woocommerce_footer_widget_areas', '4');
	for ($classic_woocommerce_i=1; $classic_woocommerce_i<=$classic_woocommerce_widget_areas; $classic_woocommerce_i++) {
		register_sidebar( array(
			'name'          => __( 'Footer Widget ', 'classic-woocommerce' ) . $classic_woocommerce_i,
			'id'            => 'footer-' . $classic_woocommerce_i,
			'description'   => '',
			'before_widget' => '<aside id="%1$s" class="widget %2$s">',
			'after_widget'  => '</aside>',
			'before_title'  => '<h3 class="widget-title">',
			'after_title'   => '</h3>',
		) );
	}
}
add_action( 'widgets_init', 'classic_woocommerce_widgets_init' );

add_action( 'wp_enqueue_scripts', 'classic_woocommerce_enqueue_styles' );
function classic_woocommerce_enqueue_styles() {
    $parenthandle = 'classic-woocommerce-style'; // This is 'twentyfifteen-style' for the Twenty Fifteen theme.
    $theme = wp_get_theme();
    wp_enqueue_style( $parenthandle, esc_url(get_template_directory_uri()) . '/style.css',
        array(),  // if the parent theme code has a dependency, copy it to here
        $theme->parent()->get('Version')
    );
    wp_enqueue_style( 'classic-woocommerce-child-style', get_stylesheet_uri(),
        array( $parenthandle ),
        $theme->get('Version') // this only works if you have Version in the style header
    );
	require get_theme_file_path( 'inc/color-scheme/custom-color-control.php' );
	wp_add_inline_style( 'classic-woocommerce-style',$classic_woocommerce_color_scheme_css );
}

function classic_woocommerce_enqueue_customizer_css() {
    wp_enqueue_style( 'classic_woocommerce-customizer-css', get_stylesheet_directory_uri() . '/css/customize-controls.css' );
}
add_action( 'customize_controls_print_styles', 'classic_woocommerce_enqueue_customizer_css' );


function classic_woocommerce_scripts() {

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'classic_woocommerce_scripts' );

add_action( 'customize_register', 'classic_woocommerce_customize_register', 11 );
function classic_woocommerce_customize_register() {
	global $wp_customize;
	$wp_customize->remove_section( 'classic_ecommerce_header_section' );
	$wp_customize->remove_section( 'classic_ecommerce_social_media_section' );

	$wp_customize->remove_setting( 'classic_ecommerce_color_scheme_one' );
	$wp_customize->remove_control( 'classic_ecommerce_color_scheme_one' );

	$wp_customize->remove_setting( 'classic_ecommerce_color_scheme_two' );
	$wp_customize->remove_control( 'classic_ecommerce_color_scheme_two' );

	$wp_customize->remove_setting( 'classic_ecommerce_top_bar' );
	$wp_customize->remove_control( 'classic_ecommerce_top_bar' );

}

// Customizer Section
function classic_woocommerce_customizer ( $wp_customize ) {
	$wp_customize->add_section('classic_woocommerce_header',array(
		'title'	=> __('Manage Header Section','classic-woocommerce'),
		'description' => __('<p class="sec-title">Manage Header Section</p>','classic-woocommerce'),
		'panel' => 'classic_ecommerce_panel_area',
	));

	$wp_customize->add_setting('classic_woocommerce_phoneno',array(
		'default'	=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('classic_woocommerce_phoneno',array(
		'label'	=> __('Phone Number','classic-woocommerce'),
		'section'	=> 'classic_woocommerce_header',
		'setting'	=> 'classic_woocommerce_phoneno',
		'type'		=> 'text'
	));

	$wp_customize->add_setting('classic_woocommerce_email',array(
		'default'	=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));

	$wp_customize->add_control('classic_woocommerce_email',array(
		'label'	=> __('Email','classic-woocommerce'),
		'section'	=> 'classic_woocommerce_header',
		'setting'	=> 'classic_woocommerce_email',
		'type'		=> 'text'
	));

	$wp_customize->add_setting( 'classic_woocommerce_header_settings_upgraded_features',array(
		'sanitize_callback' => 'sanitize_text_field'
	));
	$wp_customize->add_control('classic_woocommerce_header_settings_upgraded_features', array(
		'type'=> 'hidden',
		'description' => "<span class='customizer-upgraded-features'>Unlock Premium Customization Features:
		   <a target='_blank' href='". esc_url(CLASSIC_ECOMMERCE_PREMIUM_PAGE) ." '>Upgrade to Pro</a></span>",
		'section' => 'classic_woocommerce_header'
	));

	$wp_customize->add_setting('classic_woocommerce_color_scheme_one', array(
		'default'           => '',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'classic_woocommerce_color_scheme_one', array(
		'label'    => __('Theme Color', 'classic-woocommerce'),
		'section'  => 'classic_ecommerce_global_color',
		'settings' => 'classic_woocommerce_color_scheme_one',	
	)));

	$wp_customize->add_setting('classic_woocommerce_color_scheme_two', array(
		'default'           => '',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'classic_woocommerce_color_scheme_two', array(
		'label'    => __('Theme Color', 'classic-woocommerce'),
		'section'  => 'classic_ecommerce_global_color',
		'settings' => 'classic_woocommerce_color_scheme_two',	
	)));	

}
add_action( 'customize_register', 'classic_woocommerce_customizer' );

// Footer Link
define('CLASSIC_WOOCOMMERCE_FOOTER_LINK',__('https://www.theclassictemplates.com/products/free-wordpress-woocommerce-template','classic-woocommerce'));


if ( ! defined( 'CLASSIC_ECOMMERCE_PRO_NAME' ) ) {
	define( 'CLASSIC_ECOMMERCE_PRO_NAME', __( 'About Classic Woocommerce', 'classic-woocommerce' ));
}

if ( ! defined( 'CLASSIC_ECOMMERCE_THEME_PAGE' ) ) {
define('CLASSIC_ECOMMERCE_THEME_PAGE',__('https://www.theclassictemplates.com/collections/best-wordpress-templates','classic-woocommerce'));
}
if ( ! defined( 'CLASSIC_ECOMMERCE_SUPPORT' ) ) {
define('CLASSIC_ECOMMERCE_SUPPORT',__('https://wordpress.org/support/theme/classic-woocommerce','classic-woocommerce'));
}
if ( ! defined( 'CLASSIC_ECOMMERCE_REVIEW' ) ) {
define('CLASSIC_ECOMMERCE_REVIEW',__('https://wordpress.org/support/theme/classic-woocommerce/reviews/','classic-woocommerce'));
}
if ( ! defined( 'CLASSIC_ECOMMERCE_PRO_DEMO' ) ) {
define('CLASSIC_ECOMMERCE_PRO_DEMO',__('https://live.theclassictemplates.com/demo/classic-ecommerce','classic-woocommerce'));
}
if ( ! defined( 'CLASSIC_ECOMMERCE_PREMIUM_PAGE' ) ) {
define('CLASSIC_ECOMMERCE_PREMIUM_PAGE',__('https://www.theclassictemplates.com/products/wordpress-ecommerce-template','classic-woocommerce'));
}
if ( ! defined( 'CLASSIC_ECOMMERCE_THEME_DOCUMENTATION' ) ) {
define('CLASSIC_ECOMMERCE_THEME_DOCUMENTATION',__('https://live.theclassictemplates.com/demo/docs/classic-woocommerce-free/','classic-woocommerce'));
}

function redirect_to_classic_ecommerce_theme_info() {
    // Check if we're in the admin and on the child theme's "Theme Info" page
    if (is_admin() && isset($_GET['page']) && $_GET['page'] === 'classic-ecommerce-demo') {
        // Redirect to the parent theme's "Theme Info" page
        wp_redirect(admin_url('themes.php?page=classic-ecommerce'));
        exit;
    }
}
add_action('admin_init', 'redirect_to_classic_ecommerce_theme_info');
// Remove "Theme Demo Import" page in child theme
function remove_classic_ecommerce_demo_import_page() {
    remove_submenu_page('themes.php', 'classic-ecommerce-demo');
}
add_action('admin_menu', 'remove_classic_ecommerce_demo_import_page', 999);
if ( ! function_exists( 'classic_ecommerce_the_custom_logo' ) ) :
	/**
	 * Displays the custom logo in the child theme.
	 * This will prevent the parent theme's default logo from showing.
	 *
	 * @since classic-woocommerce
	 */
	function classic_ecommerce_the_custom_logo() {
		if ( function_exists( 'the_custom_logo' ) ) {
			if ( has_custom_logo() ) {
				the_custom_logo(); // Show the custom logo if it is set.
			}
			// If no logo is set, nothing will be displayed.
		}
	}
endif;



